Optical transitions between Landau levels: AA-stacked bilayer graphene
Author: Yen-Hung Ho|Jhao-Ying Wu|Rong-Bin Chen|Yu-Huang Chiu|Ming-Fa Lin
Description: The magneto-opticalabsorption spectra of A A -stacked bilayer graphene (AABG) exhibit two kinds of absorption peaks resulting from two groups of Landau levels(LLs). Only intragroup excitations that follow a single selection rule take place. The excitation channels are altered as the field strength approaches a critical strength. These optical properties can be comprehended by the characteristics of the LL wave functions. A comparison of AABG and A B -stacked bilayer graphene (BBG) demonstrates that the optical properties are dominated by the stacking symmetry. The presented results could offer a way to distinguish AABG from BBG and monolayer graphene.
Date: 2010/09/09

Skip to main content
1887
My Cart
Advanced Search Volume/Page Search
Publication:
Applied Physics Letters
Vol: Page:
No data available.
Please log in to see this content.
You have no subscription access to this content.
No metrics data to plot.
The attempt to load metrics for this article has failed.
The attempt to plot a graph for these metrics has failed.
The full text of this article is not currently available.
Optical transitions between Landau levels:
-stacked bilayer graphene

Yen-Hung Ho1,2, Jhao-Ying Wu1, Rong-Bin Chen3, Yu-Huang Chiu1,a) and Ming-Fa Lin1,b)
Scitation Author Page
PubMed
Google Scholar
View Affiliations Hide Affiliations
Affiliations:
1 Department of Physics, National Cheng Kung University, Tainan 701, Taiwan
2 Department of Physics, National Sun Yat-Sen University, Kaohsiung 804, Taiwan
3 Center of General Education, National Kaohsiung Marine University, Kaohsiung 830, Taiwan
a) Electronic mail: airegg.py90g@nctu.edu.tw.
b) Electronic mail: mflin@mail.ncku.edu.tw.
Appl. Phys. Lett. 97, 101905 (2010); http://dx.doi.org/10.1063/1.3488806

USD
Rent: Rent this article for
10.1063/1.3488806

- Abstract
- Full Text
- References (18)
- Cited By (35)
- Data & Media
- Metrics
- Related

### Abstract

The magneto-opticalabsorption spectra of
-stacked bilayer graphene (AABG) exhibit two kinds of absorption peaks resulting from two groups of Landau levels(LLs). Only intragroup excitations that follow a single selection rule take place. The excitation channels are altered as the field strength approaches a critical strength. These optical properties can be comprehended by the characteristics of the LL wave functions. A comparison of AABG and
-stacked bilayer graphene (BBG) demonstrates that the optical properties are dominated by the stacking symmetry. The presented results could offer a way to distinguish AABG from BBG and monolayer graphene.

© 2010 American Institute of Physics
DOI: http://dx.doi.org/10.1063/1.3488806
Received 16 April 2010 Accepted 20 August 2010 Published online 09 September 2010
Acknowledgments:

This work was supported by the NSC and NCTS of Taiwan, under the Grant Nos. NSC 95-2112-M-006-028-MY3 and NSC 97-2112-M-110-001-MY2.

### Key Topics

Absorption spectra
  12.0
Magnetooptical effects
  12.0
Wave functions
  12.0
Excited states
  9.0
Optical properties
  8.0

0
12.0

Commenting has been disabled for this content

Submit comment
Close
Comment moderation successfully completed
/content/aip/journal/apl/97/10/10.1063/1.3488806
http://aip.metastore.ingenta.com/content/aip/journal/apl/97/10/10.1063/1.3488806
Optical transitions between Landau levels: AA-stacked bilayer graphene
Appl. Phys. Lett. 97, 101905 (2010); http://dx.doi.org/10.1063/1.3488806
/content/aip/journal/apl/97/10/10.1063/1.3488806
/content/aip/journal/apl/97/10/10.1063/1.3488806

Data & Media loading...

Article metrics loading...

/content/aip/journal/apl/97/10/10.1063/1.3488806
2010-09-09
2016-08-27
10.1063/1.3488806
/content/aip/journal/apl/97/10/10.1063/1.3488806
dcterms_title,dcterms_subject,pub_keyword
-contentType:Contributor -contentType:Concept -contentType:Institution
6
3

Full text loading...

### Most read this month

Article
content/aip/journal/apl
Journal
5
3

### Most cited this month

- - ##### Organic electroluminescent diodes

    C. W. Tang and S. A. VanSlyke
    Scitation Author Page
    PubMed
    Google Scholar

- - ##### Silicon quantum wire array fabrication by electrochemical and chemical dissolution of wafers

    By L. T. Canham
    Scitation Author Page
    PubMed
    Google Scholar

- - ##### VAPOR‐LIQUID‐SOLID MECHANISM OF SINGLE CRYSTAL GROWTH

    R. S. Wagner and W. C. Ellis
    Scitation Author Page
    PubMed
    Google Scholar

- - ##### Electronic analog of the electro‐optic modulator

    Supriyo Datta and Biswajit Das
    Scitation Author Page
    PubMed
    Google Scholar

- - ##### Two‐layer organic photovoltaic cell

    By C. W. Tang
    Scitation Author Page
    PubMed
    Google Scholar

More Less

#### Access Key

- FFree Content
- OAOpen Access Content
- SSubscribed Content
- TFree Trial Content

This is a required field
Please enter a valid email address

## Oops! This section does not exist...

Use the links on this page to find existing content.

Click here to download this PDF to your device.
752b84549af89a08dbdd7fdb8b9568b5 journal.articlezxybnytfddd
Scitation: Optical transitions between Landau levels: AA-stacked bilayer graphene
http://aip.metastore.ingenta.com/content/aip/journal/apl/97/10/10.1063/1.3488806
10.1063/1.3488806
SEARCH_EXPAND_ITEM
/content/realmedia?fmt=ahah&adPositionList=
&advertTargetUrl=//oascentral.aip.org/RealMedia/ads/&sitePageValue=apl.aip.org/97/10/10.1063/1.3488806&pageURL=http://scitation.aip.org/content/aip/journal/apl/97/10/10.1063/1.3488806'
x100,x101,x102,x103,
Position1,Position2,Position3,
Right1,Right2,Right3,

- journal/journal.article
- aip/apl
- /content/aip/journal/apl/97/10/10.1063/1.3488806
- apl.aip.org/97/10/10.1063/1.3488806/Right1,Right2,Right3,Position1,Position2,Position3,x100,x101,x102,x103